@@ -2,6 +2,98 @@ import datetime
 import time
 import warnings
 import re
+import pandas as pd
+
+HOLIDAYS = [
+    {
+        "holiday_name": "元旦节",
+        "H": [
+            "2022-01-01:2022-01-03"
+        ],
+        "W": [
+        ]
+    },
+    {
+        "holiday_name": "春节",
+        "H": [
+            "2022-01-31:2022-02-06"
+        ],
+        "W": [
+            "2022-01-29:2022-01-30"
+        ]
+    },
+    {
+        "holiday_name": "清明节",
+        "H": [
+            "2022-04-03:2022-04-05"
+        ],
+        "W": [
+            "2022-04-02"
+        ]
+    },
+    {
+        "holiday_name": "劳动节",
+        "H": [
+            "2022-04-30:2022-05-04"
+        ],
+        "W": [
+            "2022-04-24",
+            "2022-05-07"
+        ]
+    },
+    {
+        "holiday_name": "端午节",
+        "H": [
+            "2022-06-03:2022-06-05"
+        ],
+        "W": [
+        ]
+    },
+    {
+        "holiday_name": "中秋节",
+        "H": [
+            "2022-09-10:2022-09-12"
+        ],
+        "W": [
+        ]
+    },
+    {
+        "holiday_name": "国庆节",
+        "H": [
+            "2022-10-01:2022-10-07"
+        ],
+        "W": [
+            "2022-10-08:2022-10-09"
+        ]
+    }
+]
+
+
+class ChineseCalendar:
+    def __init__(self, start_date, n=365):
+        __tidx = pd.date_range(start=start_date, periods=365, freq="1D")
+        self.ts = pd.Series(__tidx).map(lambda x: x.dayofweek)
+        self.ts.index = __tidx
+        for holiday in HOLIDAYS:
+            for itvl in holiday["H"]:
+                self.__refresh_calendar(itvl, 7)
+            for itvl in holiday["W"]:
+                self.__refresh_calendar(itvl, -1)
+
+    def __refresh_calendar(self, date_or_interval, val):
+        if ":" in date_or_interval:
+            _start_idx, _end_idx = date_or_interval.split(":")
+            self.ts[_start_idx:_end_idx] = val
+        else:
+            self.ts[date_or_interval] = val
+
+    def count_WDAY(self, start_date, end_date):
+        # print(self.ts[self.ts<5][start_date:end_date])
+        return self.ts[self.ts < 5][start_date:end_date].shape[0]
+
+    def move_WDAY(self, start_date, n):
+        # print(self.ts[self.ts<5][start_date:end_date])
+        return strftime(self.ts[self.ts < 5][start_date:].index[n - 1],fmt="%Y-%m-%d")
 
 
 class InvalidInputError(Exception):
