@@ -1,5 +1,5 @@
 import unittest
-from spongebox.financebox.loan import repay_plan_factory
+from spongebox.financebox.loanbox import repay_plan_factory
 
 
 class MyTestCase(unittest.TestCase):
