@@ -2,8 +2,8 @@ import unittest
 from spongebox.mediabox import Tailor
 
 frgs = []
-# frgs.append(("000000", "010818"))
-frgs.append(("004455", "010203"))
+frgs.append(("000000", "010438"))
+# frgs.append(("000106", "000136"))
 # Tailor("F:\\download\\20\\vedio.mp4").launch(frgs)
 # Tailor("F:\\download\\20\\FCDC-123.mp4",output_dir="F:\\download\\20").launch(frgs)
-Tailor("E:\\download\\REBD-450\\REBD-450.mp4",output_dir="F:\\download\\20").launch(frgs)
\ No newline at end of file
+Tailor("C:\\Users\\LuoJi\\Desktop\\HJMO-457.mp4",output_dir="C:\\Users\\LuoJi\\Desktop").launch(frgs)
\ No newline at end of file
